function [x y] = getMiniAmpSample(A,F,n)

% A = amplitudes values to use with n minis per cell
% F = ID of cell from which minis were taken
% n = number of minis to take from each culture
% x = cell array of minis, each with double of length n
% y = cell array containing ID of cell from which minis are taken

for i = 1:length(F)
    x_tmp = cell2mat(A(i,1));
    x_tmp = x_tmp(x_tmp>=5 & x_tmp<200);
    if length(x_tmp) >= n
        ind = randsample(length(x_tmp),n);
        x{i,1} = x_tmp(ind);
        y{i,1} = F(i,1);
    else
        continue
    end
end
